import { Switch, Route } from "wouter";
import { queryClient } from "./lib/queryClient";
import { QueryClientProvider } from "@tanstack/react-query";
import { Toaster } from "@/components/ui/toaster";
import { TooltipProvider } from "@/components/ui/tooltip";
import { Navigation } from "@/components/Navigation";
import { CookieConsent } from "@/components/CookieConsent";
import Home from "@/pages/Home";
import Cars from "@/pages/Cars";
import About from "@/pages/About";
import Terms from "@/pages/Terms";
import Admin from "@/pages/Admin";
import NotFound from "@/pages/not-found";
import { LanguageProvider, useLanguage } from "@/contexts/LanguageContext";
import { AuthProvider } from "@/contexts/AuthContext";
import { HelmetProvider } from 'react-helmet-async';

function Router() {
  return (
    <Switch>
      <Route path="/" component={Home} />
      <Route path="/cars" component={Cars} />
      <Route path="/about" component={About} />
      <Route path="/terms" component={Terms} />
      <Route path="/admin" component={Admin} />
      <Route component={NotFound} />
    </Switch>
  );
}

function App() {
  return (
    <HelmetProvider>
      <LanguageProvider>
        <QueryClientProvider client={queryClient}>
          <AuthProvider>
            <TooltipProvider>
              <div className="min-h-screen bg-background">
                <Navigation />
                <main>
                  <Router />
                </main>
                <Footer />
              </div>
              <Toaster />
              <CookieConsent />
            </TooltipProvider>
          </AuthProvider>
        </QueryClientProvider>
      </LanguageProvider>
    </HelmetProvider>
  );
}

function Footer() {
  const { t } = useLanguage();
  
  return (
    <footer className="bg-neutral-900 text-white py-12">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="grid grid-cols-1 md:grid-cols-4 gap-8">
          <div>
            <div className="text-2xl font-bold mb-4">Rent a Car Saraj</div>
            <p className="text-neutral-400 mb-4">
              {t("footerDescription")}
            </p>
            <img
              src="https://images.unsplash.com/photo-1556742049-0cfed4f6a45d?ixlib=rb-4.0.3&auto=format&fit=crop&w=400&h=200"
              alt="Customer Service"
              className="rounded-lg w-full h-32 object-cover"
            />
          </div>

          <div>
            <h3 className="text-lg font-semibold mb-4">{t("quickLinks")}</h3>
            <ul className="space-y-2">
              <li><a href="/" className="text-neutral-400 hover:text-white transition-colors">{t("home")}</a></li>
              <li><a href="/cars" className="text-neutral-400 hover:text-white transition-colors">{t("ourFleet")}</a></li>
              <li><a href="/about" className="text-neutral-400 hover:text-white transition-colors">{t("about")}</a></li>
              <li><a href="/terms" className="text-neutral-400 hover:text-white transition-colors">{t("terms")}</a></li>
              <li><a href="https://www.booking.com/Pulse-kBcHg8" target="_blank" rel="noopener noreferrer" className="text-neutral-400 hover:text-white transition-colors">{t("apartmentRental")}</a></li>
            </ul>
          </div>

          <div>
            <h3 className="text-lg font-semibold mb-4">{t("contactInfo")}</h3>
            <ul className="space-y-2 text-neutral-400">
              <li>📞 +387 62 127 217</li>
              <li>📧 rentacarsaraj@gmail.com</li>
              <li>📍 Reufa Muhića 1, Sarajevo, Bosnia and Herzegovina 71000</li>
              <li>🕒 {t("customerSupportAvailable")}</li>
            </ul>
          </div>

          <div>
            <h3 className="text-lg font-semibold mb-4">{t("followUs")}</h3>
            <div className="flex space-x-4 mb-4">
              <a href="#" className="text-neutral-400 hover:text-white transition-colors">Facebook</a>
              <a href="https://www.instagram.com/rentacar_saraj?igsh=ZGdyaWpsY3F2Z2ht&utm_source=qr" target="_blank" rel="noopener noreferrer" className="text-neutral-400 hover:text-white transition-colors">Instagram</a>
              <a href="#" className="text-neutral-400 hover:text-white transition-colors">Twitter</a>
            </div>
            <img
              src="https://images.unsplash.com/photo-1497366754035-f200968a6e72?ixlib=rb-4.0.3&auto=format&fit=crop&w=400&h=200"
              alt="Our Office"
              className="rounded-lg w-full h-32 object-cover"
            />
          </div>
        </div>

        <div className="border-t border-neutral-800 mt-8 pt-8 text-center text-neutral-400">
          <p>&copy; 2025 Rent a Car Saraj. {t("rightsReserved")}.</p>
        </div>
      </div>
    </footer>
  );
}

export default App;
